==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPivotDimensionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDetailDescriptionMetadata } from "./WebPivotDimensionDetailDescriptionMetadata";
import { WebPivotDimensionEventArgsDescription } from "./WebPivotDimensionEventArgsDescription";
/**
 * @hidden
 */
export let WebPivotDimensionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotDimensionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotDimensionEventArgsDescriptionMetadata.a == null) {
                WebPivotDimensionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotDimensionEventArgsDescriptionMetadata.c(WebPivotDimensionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPivotDimensionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPivotDimensionEventArgsDescriptionMetadata.a);
            WebPivotDimensionDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotDimensionEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebPivotDimensionDetail");
        }
        static d(a) {
            WebPivotDimensionEventArgsDescriptionMetadata.b(a);
            a.ad("WebPivotDimensionEventArgs", () => new WebPivotDimensionEventArgsDescription());
            a.ac("WebPivotDimensionEventArgs", WebPivotDimensionEventArgsDescriptionMetadata.a);
        }
    }
    WebPivotDimensionEventArgsDescriptionMetadata.$t = markType(WebPivotDimensionEventArgsDescriptionMetadata, 'WebPivotDimensionEventArgsDescriptionMetadata');
    WebPivotDimensionEventArgsDescriptionMetadata.a = null;
    return WebPivotDimensionEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPivotDimensionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDetailDescriptionMetadata } from "./WebPivotDimensionDetailDescriptionMetadata";
import { WebPivotDimensionEventArgsDescription } from "./WebPivotDimensionEventArgsDescription";
/**
 * @hidden
 */
export let WebPivotDimensionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotDimensionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotDimensionEventArgsDescriptionMetadata.a == null) {
                WebPivotDimensionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotDimensionEventArgsDescriptionMetadata.c(WebPivotDimensionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPivotDimensionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotDimensionEventArgsDescriptionMetadata.a);
            WebPivotDimensionDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotDimensionEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebPivotDimensionDetail");
        }
        static d(a) {
            WebPivotDimensionEventArgsDescriptionMetadata.b(a);
            a.ae("WebPivotDimensionEventArgs", () => new WebPivotDimensionEventArgsDescription());
            a.ad("WebPivotDimensionEventArgs", WebPivotDimensionEventArgsDescriptionMetadata.a);
        }
    }
    WebPivotDimensionEventArgsDescriptionMetadata.$t = markType(WebPivotDimensionEventArgsDescriptionMetadata, 'WebPivotDimensionEventArgsDescriptionMetadata');
    WebPivotDimensionEventArgsDescriptionMetadata.a = null;
    return WebPivotDimensionEventArgsDescriptionMetadata;
})();
